cellText: Set the value in a cell

View source: R/shiny.R

cellTextR Documentation

Set the value in a cell

Description

Sets the text of a cell, requires a x-spreadsheet proxy to interact with and valid arguments. Indices are expected to be 1-based (R).

Usage

cellText(proxy, row, col, text, sheetIndex, triggerChange = TRUE)

Arguments

proxy

The x-spreadsheet proxy object

row

The row index of the cell

col

The column index of the cell

text

The text to set the cell to

sheetIndex

The index of the sheet to set the cell in, uses R 1-based indexing.

triggerChange

Whether to trigger a change event, defaults to TRUE, will trigger an update to the _change input value


MichaelHogers/RXSpreadsheet documentation built on July 18, 2023, 7:41 p.m.