| deleteSheet | R Documentation |
Deletes a sheet from the spreadsheet, defaults to deleting the active sheet. Only deletes sheets if at least two sheets are present.
deleteSheet(proxy, sheetIndex = NULL)
proxy |
The x-spreadsheet proxy object |
sheetIndex |
The index of the sheet to delete, uses R 1-based indexing. If left NULL, the active sheet is deleted. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.