getData: Get the data object

View source: R/shiny.R

getDataR Documentation

Get the data object

Description

Retrieves the data object by sending a call to the client, which then sends the data to an input with name paste0(proxy, "_data")

By retrieving the data object from the client, you can get the current data in the spreadsheet, including all formatting and other custom settings.

TO DO: add logic to: load the spreadsheet via the getData data object add logic to parse the data object into a list containing data.frames

Usage

getData(proxy)

Arguments

proxy

The x-spreadsheet proxy object


MichaelHogers/RXSpreadsheet documentation built on July 18, 2023, 7:41 p.m.