| loadData | R Documentation |
Reload all data
loadData(proxy, data, processing = TRUE, triggerChange = TRUE)
proxy |
The x-spreadsheet proxy object |
data |
The new data, must be a data.frame or a named list with data.frame entries |
processing |
Whether to process the data, defaults to TRUE. If the data is being loaded based on previously stored JSON data, set this to FALSE. If a data.frame or a list of data.frames is provided, set this to TRUE. |
triggerChange |
Whether to trigger a change event, defaults to TRUE, will trigger an update to the _change input value |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.