| runExamples | R Documentation |
Launch xSpreadsheet example applications, and optionally, your system's web browser.
runExamples(example = NA, port = 3000)
example |
The name of the example to run, or |
port |
The port to run the application on. Defaults to 3000. |
## Only run this example in interactive R sessions
if (interactive()) {
# List all available examples
runExamples()
# Run one of the examples
runExamples("01_spreadSheet")
# Print the directory containing the code for all examples
system.file("examples", package="xSpreadsheet")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.