| cellText | R Documentation |
Sets the text of a cell, requires a x-spreadsheet proxy to interact with and valid arguments. Indices are expected to be 1-based (R).
cellText(proxy, row, col, text, sheetIndex, triggerChange = TRUE)
proxy |
The x-spreadsheet proxy object |
row |
The row index of the cell |
col |
The column index of the cell |
text |
The text to set the cell to |
sheetIndex |
The index of the sheet to set the cell in, uses R 1-based indexing. |
triggerChange |
Whether to trigger a change event, defaults to TRUE, will trigger an update to the _change input value |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.